import {
  Button,
  Dialog,
  DialogActions,
  DialogContent,
  DialogTitle,
} from "@mui/material";
import React from "react";
import { UpdateAccommodationReservation } from "../../api/accommodations/AccommodationsReservationsApi";
import { useAccommodations } from "../../widgets/accommodations/BaseAccommodationsRoute";
import { PropDateInput } from "../../widgets/forms/PropDateInput";
import { PropSelect } from "../../widgets/forms/PropSelect";

export function UpdateReservationDialog(p: {
  open: boolean;
  create: boolean;
  reservation?: UpdateAccommodationReservation;
  onClose: () => void;
  onSubmitted: (c: UpdateAccommodationReservation) => void;
}): React.ReactElement {
  const accommodations = useAccommodations();

  const [reservation, setReservation] = React.useState<
    UpdateAccommodationReservation | undefined
  >();

  const clearForm = () => {
    setReservation(undefined);
  };

  const cancel = () => {
    clearForm();
    p.onClose();
  };

  const submit = async () => {
    clearForm();
    p.onSubmitted(reservation!);
  };

  React.useEffect(() => {
    if (!reservation) setReservation(p.reservation);
  }, [p.open, p.reservation]);

  // TODO : check availability

  return (
    <Dialog open={p.open} onClose={cancel}>
      <DialogTitle>
        {p.create ? "Création" : "Mise à jour"} d'une réservation
      </DialogTitle>
      <DialogContent style={{ display: "flex", flexDirection: "column" }}>
        <PropSelect
          editing={p.create}
          label="Logement ciblé"
          onValueChange={(v) => {
            setReservation((a) => {
              return {
                ...a!,
                accommodation_id: Number(v),
              };
            });
          }}
          options={accommodations.accommodations.openToReservationList.map(
            (a) => {
              return { label: a.name, value: a.id.toString() };
            }
          )}
          value={reservation?.accommodation_id?.toString()}
        />

        <PropDateInput
          editable
          label="Date de début"
          value={reservation?.start}
          onChange={(s) => {
            setReservation((r) => {
              return { ...r!, start: s ?? -1 };
            });
          }}
        />

        <PropDateInput
          editable
          label="Date de fin"
          value={reservation?.end}
          lastSecOfDay={true}
          onChange={(s) => {
            setReservation((r) => {
              return { ...r!, end: s ?? -1 };
            });
          }}
        />

        {/* Constraint start and end */}

        {/* TODO : la suite */}
      </DialogContent>
      <DialogActions>
        <Button onClick={cancel}>Annuler</Button>
        <Button
          onClick={submit}
          disabled={
            !(
              (reservation?.accommodation_id ?? -1) > 0 &&
              (reservation?.start ?? -1) > 0 &&
              (reservation?.end ?? -1) > (reservation?.start ?? 0)
            )
          }
        >
          {p.create ? "Créer" : "Mettre à jour"}
        </Button>
      </DialogActions>
    </Dialog>
  );
}
